@@ -1,10 +1,6 @@
-( cd bin ; rm -rf egrep )
-( cd bin ; ln -sf grep egrep )
-( cd bin ; rm -rf fgrep )
-( cd bin ; ln -sf grep fgrep )
-( cd usr/bin ; rm -rf grep )
-( cd usr/bin ; ln -sf ../../bin/grep grep )
 ( cd usr/bin ; rm -rf egrep )
 ( cd usr/bin ; ln -sf ../../bin/egrep egrep )
+( cd usr/bin ; rm -rf grep )
+( cd usr/bin ; ln -sf ../../bin/grep grep )
 ( cd usr/bin ; rm -rf fgrep )
 ( cd usr/bin ; ln -sf ../../bin/fgrep fgrep )
